import logging

LEVEL_MAP = {
    "debug": logging.DEBUG,
    "info": logging.INFO,
    "success": logging.SUCCESS,
    "warning": logging.WARNING,
    "error": logging.ERROR,
    "critical": logging.CRITICAL,
}
